function msh = createmesh( obj, fmax, isRegular )
% create spring mesh for the extended plate

if nargin < 2; fmax = 3e3; end
if nargin < 3; isRegular = true; end


tic

lmin = 0.1*sqrt(2*pi/fmax)*(min(obj.rigidity([1 3]))/obj.mass_density/mean(obj.thickness))^0.25;
xext = [ 0, 0, obj.width, obj.width];
yext = [ 0, obj.length, obj.length, 0 ];

if isRegular
    xvec = -lmin:lmin:obj.width+lmin;
    yvec = -lmin*sqrt(3)/2:lmin*sqrt(3)/2:obj.length*sqrt(3)/2;

    [ Cx, Cy ] = meshgrid(xvec, yvec);
    Cx(1:2:end,:) = Cx(1:2:end,:) + lmin/2;
    xm = Cx(:);
    ym = Cy(:);    

    inpoint = inpolygon(xm,ym,obj.x_extended,obj.y_extended);
    xm(inpoint) = [];
    ym(inpoint) = [];

    msh = [xm(:), ym(:)];

    nstr = num2str(length(xm));
    lminstr = num2str(lmin*1000,'%.2f');
    disp(['The mesh of ',nstr,' points has been successfully generated. Maximal distance is ',lminstr,'mm'])

    obj.length = max(ym(:))-min(ym(:));
    obj.width = max(xm(:))-min(xm(:));
    obj.mesh = msh;
    obj.order = length(xm);
else
    R1 = [ 2; length(obj.x_extended)-1; obj.x_extended(1:end-1); obj.y_extended(1:end-1) ];
    Rbase = [ 3; 4; xext(:); yext(:) ];

    Rbase = [ Rbase; zeros(length(R1)-length(Rbase),1) ];

    gm = [Rbase,R1];
    sf = 'Rbase-R1';
    ns = char('Rbase','R1')';
    model = createpde;
    try
        dl = decsg(gm, sf, ns);
        pg = geometryFromEdges(model, dl);
        p = initmesh(pg,'Hmax',lmin);
        msh = p.';
        et = toc ;
        disp(['Mesh generated by Matlab in ',num2str(et, '%.2f'),' seconds'])
        obj.mesh = msh;
        obj.order = size(msh,1);
    catch
        disp('No mesh has been generated: the panel does not need to be extended')
    end
  
end