function [XI, YI, ZI, coor, V] = loadND(fic, num_inst, raff)
% [XI, YI, ZI, coor, V] = loadND(fic, num_inst, raff) 	
  XI = []; YI = []; ZI = []; coor = []; V = [];
  % we read a file generated by montjoie

  % if the grid number is not specified, we take the first one
  % if the refinement ratio is not specified, we take one
  if (nargin == 1)
    num_inst = 1;
    raff = 1;
  end
  if (nargin == 2)
    raff = 1;
  end
  
  % we read the number of grids
  fid = fopen(fic, 'r');
  nb_grids = fread(fid, 1, 'int');
  
  % the dimension
  dim = fread(fid, 1, 'int');
  
  % type of data (0 : float, 1 : double, 2 : complex float, 3 : complex double)
  type_data = fread(fid, 1, 'int');
  prec = 'double'; prec_size = 8;
  if ((type_data == 0)||(type_data == 2))
    prec = 'float'; prec_size = 4;
  end
  cplx = 1;
  if (type_data >= 2)
    cplx = 2;
  end
  prec_size = prec_size*cplx;
  
  % type of grid
  type_grid = fread(fid, 1, 'int');

  if (dim == 1)
    % Dimension 1 :
    xmin = fread(fid, 1, prec);    
    xmax = fread(fid, 1, prec);
    nbx = fread(fid, 1, 'int');    
    n = fread(fid, 1, 'int');
    taille = cplx*nbx;
    data = fread(fid, taille, prec);
    if (cplx == 2)
      M = data(1:2:taille)+1i*data(2:2:taille);
    else
      M = data;
    end
    fclose(fid);
    
    V = M;
    XI = linspace(xmin, xmax, nbx);
  elseif (dim == 2)
    % Dimension 2 :

    % depending the type of grid, we read the appropriate datas
    if (type_grid == 0)

      % SismoPlane
      offset = 0;
      for i = 1:nb_grids
        xmin_(i) = fread(fid, 1, prec);
        xmax_(i) = fread(fid, 1, prec);
        nbx_(i) = fread(fid, 1, 'int');
        ymin_(i) = fread(fid, 1, prec);
        ymax_(i) = fread(fid, 1, prec);
        nby_(i) = fread(fid, 1, 'int');
        if (i < num_inst)
          offset = offset + nbx_(i)*nby_(i);
        end
      end 
      xmin = xmin_(num_inst); xmax = xmax_(num_inst);
      ymin = ymin_(num_inst); ymax = ymax_(num_inst);
      nbx = nbx_(num_inst); nby = nby_(num_inst);
      n = fread(fid, 1, 'int');
      taille = cplx*nbx*nby;
      % we read values related to the required snapshot
      fseek(fid, offset*prec_size, 'cof');
      data = fread(fid, taille, prec);

      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);

      X = linspace(xmin, xmax, nbx);
      Y = linspace(ymin, ymax, nby);
      U = reshape(M, nbx, nby); U = U.';
      if (raff == 1)
        V = U;
        [XI,YI] = meshgrid(X,Y);
      else
        [XI,YI] = meshgrid(linspace(xmin, xmax, raff*nbx),linspace(ymin, ymax, raff*nby));
        V = interp2(X,Y,U,XI,YI);
      end
      
    elseif (type_grid == 1)

      % SismoLine
      offset = 0;
      for i = 1:nb_grids
        xmin_(i) = fread(fid, 1, prec);
        xmax_(i) = fread(fid, 1, prec);
        ymin_(i) = fread(fid, 1, prec);
        ymax_(i) = fread(fid, 1, prec);
        nbx_(i) = fread(fid, 1, 'int');
        if (i < num_inst)
          offset = offset + nbx_(i);
        end
      end 
      xmin = xmin_(num_inst); xmax = xmax_(num_inst);
      ymin = ymin_(num_inst); ymax = ymax_(num_inst);
      nbx = nbx_(num_inst);
      n = fread(fid, 1, 'int');
      taille = cplx*nbx;
      % we read values related to the required snapshot
      fseek(fid, offset*prec_size, 'cof');
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);

      X = linspace(xmin, xmax, nbx);
      Y = linspace(ymin, ymax, nbx);      
      U = reshape(M, nbx, 1);
      if (raff == 1)
        V = U;
        XI = X;
        YI = Y;
      else
        T = linspace(0, 1, nbx); TI = linspace(0, 1, raff*nbx);
        XI = linspace(xmin, xmax, raff*nbx);
        YI = linspace(ymin, ymax, raff*nbx);
        V = interp1(T, U, TI);
      end
      
    elseif (type_grid == 2)

      % SismoPoint
      offset = 0;
      for i = 1:nb_grids
        xmin_(i) = fread(fid, 1, prec);
        ymin_(i) = fread(fid, 1, prec);
        if (i < num_inst)
          offset = offset + 1;
        end
      end 
      xmin = xmin_(num_inst);
      ymin = ymin_(num_inst);
      n = fread(fid, 1, 'int');
      taille = cplx;
      % we read values related to the required snapshot
      fseek(fid, offset*prec_size, 'cof');
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);

      XI = xmin;
      YI = ymin;
      V = M;
      
    elseif (type_grid == 3)

      % SismoCircle
      offset = 0;
      for i = 1:nb_grids
        xmin_(i) = fread(fid, 1, prec);
        ymin_(i) = fread(fid, 1, prec);
        radius_(i) = fread(fid, 1, prec);
        nbx_(i) = fread(fid, 1, 'int');
        if (i < num_inst)
          offset = offset + nbx_(i);
        end
      end 
      xmin = xmin_(num_inst); radius = radius_(num_inst);
      ymin = ymin_(num_inst);
      nbx = nbx_(num_inst);
      n = fread(fid, 1, 'int');
      taille = cplx*nbx;
      % we read values related to the required snapshot
      fseek(fid, offset*prec_size, 'cof');
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);

      teta = linspace(0, 2*pi, nbx+1); teta = teta(1:nbx);
      X = radius*cos(teta) + xmin;
      Y = radius*sin(teta) + ymin;
      U = reshape(M, nbx, 1);
      if (raff == 1)
        V = U;
        XI = X;
        YI = Y;
      else
        T = linspace(0, 1, nbx); TI = linspace(0, 1, raff*nbx);
        teta = linspace(0, 2*pi, raff*nbx+1); teta = teta(1:raff*nbx);
        XI = radius*cos(teta) + xmin;
        YI = radius*sin(teta) + ymin;
        V = interp1(T, U, TI);
      end

    elseif (type_grid == 4)
      
      % SismoGrille (for axisymmetric problems)
      offset = 0;
      for i = 1:nb_grids
        xmin_(i) = fread(fid, 1, prec);
        xmax_(i) = fread(fid, 1, prec);
        nbx_(i) = fread(fid, 1, 'int');
        ymin_(i) = fread(fid, 1, prec);
        ymax_(i) = fread(fid, 1, prec);
        nby_(i) = fread(fid, 1, 'int');
        zmin_(i) = fread(fid, 1, prec);
        zmax_(i) = fread(fid, 1, prec);
        nbz_(i) = fread(fid, 1, 'int');
        coorx_(i) = fread(fid, 1, prec);
        coory_(i) = fread(fid, 1, prec);
        coorz_(i) = fread(fid, 1, prec);
        if (i < num_inst)
          offset = offset + nbx_(i)*nby_(i) + nbx_(i)*nbz_(i) + nby_(i)*nbz_(i);
        end
      end
      n = fread(fid, 1, 'int');
      xmin = xmin_(num_inst); xmax = xmax_(num_inst); nbx = nbx_(num_inst);
      ymin = ymin_(num_inst); ymax = ymax_(num_inst); nby = nby_(num_inst);
      zmin = zmin_(num_inst); zmax = zmax_(num_inst); nbz = nbz_(num_inst);
      coor = [coorx_(num_inst); coory_(num_inst); coorz_(num_inst)];
      taille = cplx*(nbx*nby + nbx*nbz + nby*nbz);
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);
      
      X = linspace(xmin, xmax, nbx);
      Y = linspace(ymin, ymax, nby);
      Z = linspace(zmin, zmax, nbz);

      V1 = reshape(M(1:nby*nbz), nby, nbz);
      V2 = reshape(M((nby*nbz+1):(nbx*nbz+nby*nbz)), nbx, nbz);
      V3 = reshape(M((nby*nbz+nbx*nbz+1):(nbx*nby+nbx*nbz+nby*nbz)), nbx, nby);

      nbxy = max(nbx,nby);
      nbyz = max(nby,nbz);
      U = zeros(nbxy, nbyz, 3);
      V1c = V1; V2c = V2; V3c = V3;
      if (nby < nbxy)
        V1c = interp2(Y,Z,V1,linspace(ymin,ymax,nbxy),linspace(zmin,zmax,nbyz)');
      end
      if (nbz < nbyz)
        V1c = interp2(Y,Z,V1,linspace(ymin,ymax,nbxy),linspace(zmin,zmax,nbyz)');
        V2c = interp2(X,Z,V2,linspace(xmin,xmax,nbxy),linspace(zmin,zmax,nbyz)');
      end
      if (nbx < nbxy)
        V2c = interp2(X,Z,V2,linspace(xmin,xmax,nbxy),linspace(zmin,zmax,nbyz)');
        V3c = interp2(X,Y,V3,linspace(xmin,xmax,nbxy),linspace(ymin,ymax,nbyz)');
      end
      if (nby < nbyz)
        V3c = interp2(X,Y,V3,linspace(xmin,xmax,nbxy),linspace(ymin,ymax,nbyz)');
      end
      
      U(:,:,1) = transpose(V1c);
      U(:,:,2) = V2c;
      U(:,:,3) = V3c;
      if (raff == 1)
        V = U;
        XI = X; YI = Y; ZI = Z;
      else
        [YI,ZI] = meshgrid(linspace(ymin, ymax, raff*nby),linspace(zmin, zmax, raff*nbz));
        V1 = interp2(Y, Z, V1, YI, ZI);
        [XI,ZI] = meshgrid(linspace(xmin, xmax, raff*nbx),linspace(zmin, zmax, raff*nbz));
        V2 = interp2(X, Z, V2, XI, ZI);
        [XI,YI] = meshgrid(linspace(xmin, xmax, raff*nbx),linspace(ymin, ymax, raff*nby));
        V3 = interp2(X, Y, V3, XI, YI);
        V(:,:,1) = V1; V(:,:,2) = V2; V(:,:,3) = V3;
        XI = linspace(xmin,xmax,raff*nbx);
        YI = linspace(ymin,ymax,raff*nby);
        ZI = linspace(zmin,zmax,raff*nbz);
      end
      
    elseif (type_grid == 5)

      % SismoCircleAxi
      offset = 0;
      for i = 1:nb_grids
        centerx_(i) = fread(fid, 1, prec);
        centery_(i) = fread(fid, 1, prec);
        centerz_(i) = fread(fid, 1, prec);
        normalex_(i) = fread(fid, 1, prec);
        normaley_(i) = fread(fid, 1, prec);
        normalez_(i) = fread(fid, 1, prec);
        radiusA_(i) = fread(fid, 1, prec);
        radiusB_(i) = fread(fid, 1, prec);
        nbx_(i) = fread(fid, 1, 'int');
        if (i < num_inst)
          offset = offset + nbx_(i);
        end
      end 
      centerx = centerx_(num_inst); radiusA = radiusA_(num_inst);
      centery = centery_(num_inst); radiusB = radiusB_(num_inst);
      centerz = centerz_(num_inst); normale(1) = normalex_(num_inst);
      normale(2) = normaley_(num_inst); normale(3) = normalez_(num_inst);
      nbx = nbx_(num_inst);
      n = fread(fid, 1, 'int');
      taille = cplx*nbx;
      % we read values related to the required snapshot
      fseek(fid, offset*prec_size, 'cof');
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);

      % finding the two vectors of plane, knowing the normale
      [coord, perm] = sort(abs(normale))
      vec_u = zeros(3,1); vec_u(perm(3)) = -normale(perm(2));
      vec_u(perm(2)) = normale(perm(3));
      vec_v(1) = normale(2)*vec_u(3) - normale(3)*vec_u(2);
      vec_v(2) = normale(3)*vec_u(1) - normale(1)*vec_u(3);
      vec_v(3) = normale(1)*vec_u(2) - normale(2)*vec_u(1);
      
      U = reshape(M, nbx, 1);
      if (raff == 1)
        V = U;
        teta = linspace(0, 2*pi, nbx+1); teta = teta(1:nbx);
        XI = radiusA*vec_u(1)*cos(teta) + radiusB*vec_v(1)*sin(teta) + centerx;
        YI = radiusA*vec_u(2)*cos(teta) + radiusB*vec_v(2)*sin(teta) + centery;
        ZI = radiusA*vec_u(3)*cos(teta) + radiusB*vec_v(3)*sin(teta) + centerz;
      else
        T = linspace(0, 1, nbx); TI = linspace(0, 1, raff*nbx);
        teta = linspace(0, 2*pi, raff*nbx+1); teta = teta(1:raff*nbx);
        XI = radiusA*vec_u(1)*cos(teta) + radiusB*vec_v(1)*sin(teta) + centerx;
        YI = radiusA*vec_u(2)*cos(teta) + radiusB*vec_v(2)*sin(teta) + centery;
        ZI = radiusA*vec_u(3)*cos(teta) + radiusB*vec_v(3)*sin(teta) + centerz;
        V = interp1(T, U, TI);
      end

    elseif (type_grid == 6)

      % SismoPointsFile
      offset = 0;
      for i = 1:nb_grids
        nbx_(i) = fread(fid, 1, 'int');
        PT_(i).coor = fread(fid, 2*nbx_(i), prec);
        if (i < num_inst)
          offset = offset + nbx_(i);
        end
      end 
      PT = PT_(num_inst).coor;
      nbx = nbx_(num_inst);
      n = fread(fid, 1, 'int');
      taille = cplx*nbx;
      % we read values related to the required snapshot
      fseek(fid, offset*prec_size, 'cof');
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);

      XI = PT(1:2:end);
      YI = PT(2:2:end);
      V = reshape(M, nbx, 1);
      
    elseif (type_grid == 7)

      % SismoPointsFileAxi
      offset = 0;
      for i = 1:nb_grids
        nbx_(i) = fread(fid, 1, 'int');
        PT_(i).coor = fread(fid, 3*nbx_(i), prec);
        if (i < num_inst)
          offset = offset + nbx_(i);
        end
      end 
      PT = PT_(num_inst).coor;
      nbx = nbx_(num_inst);
      n = fread(fid, 1, 'int');
      taille = cplx*nbx;
      % we read values related to the required snapshot
      fseek(fid, offset*prec_size, 'cof');
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);

      XI = PT(1:3:end);
      YI = PT(2:3:end);
      ZI = PT(3:3:end);
      V = reshape(M, nbx, 1);

    end

  else
    
    % Dimension 3
    if (type_grid == 0)
      
      % SismoGrille3D
      offset = 0;
      for i = 1:nb_grids
        xmin_(i) = fread(fid, 1, prec);
        xmax_(i) = fread(fid, 1, prec);
        nbx_(i) = fread(fid, 1, 'int');
        ymin_(i) = fread(fid, 1, prec);
        ymax_(i) = fread(fid, 1, prec);
        nby_(i) = fread(fid, 1, 'int');
        zmin_(i) = fread(fid, 1, prec);
        zmax_(i) = fread(fid, 1, prec);
        nbz_(i) = fread(fid, 1, 'int');
        if (i < num_inst)
          offset = offset + nbx_(i)*nby_(i)*nbz_(i);
        end
      end
      n = fread(fid, 1, 'int');
      xmin = xmin_(num_inst); xmax = xmax_(num_inst); nbx = nbx_(num_inst);
      ymin = ymin_(num_inst); ymax = ymax_(num_inst); nby = nby_(num_inst);
      zmin = zmin_(num_inst); zmax = zmax_(num_inst); nbz = nbz_(num_inst);
      taille = cplx*(nbx*nby*nbz);
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);
      
      X = linspace(xmin, xmax, nbx);
      Y = linspace(ymin, ymax, nby);
      Z = linspace(zmin, zmax, nbz);

      if (raff == 1)
        V = reshape(M, nbx, nby, nbz);
        XI = X; YI = Y; ZI = Z;
      else
        XI = linspace(xmin, xmax, nbx*raff);
        YI = linspace(ymin, ymax, nby*raff);
        ZI = linspace(zmin, zmax, nbz*raff);
        U = reshape(M, nbx, nby, nbz);
        V = interp3(X, Y, Z, U, XI, YI, ZI);
      end

      
    elseif (type_grid == 1)

      % SismoGrille
      offset = 0;
      for i = 1:nb_grids
        xmin_(i) = fread(fid, 1, prec);
        xmax_(i) = fread(fid, 1, prec);
        nbx_(i) = fread(fid, 1, 'int');
        ymin_(i) = fread(fid, 1, prec);
        ymax_(i) = fread(fid, 1, prec);
        nby_(i) = fread(fid, 1, 'int');
        zmin_(i) = fread(fid, 1, prec);
        zmax_(i) = fread(fid, 1, prec);
        nbz_(i) = fread(fid, 1, 'int');
        coorx_(i) = fread(fid, 1, prec);
        coory_(i) = fread(fid, 1, prec);
        coorz_(i) = fread(fid, 1, prec);
        if (i < num_inst)
          offset = offset + nbx_(i)*nby_(i) + nbx_(i)*nbz_(i) + nby_(i)*nbz_(i);
        end
      end
      n = fread(fid, 1, 'int');
      xmin = xmin_(num_inst); xmax = xmax_(num_inst); nbx = nbx_(num_inst);
      ymin = ymin_(num_inst); ymax = ymax_(num_inst); nby = nby_(num_inst);
      zmin = zmin_(num_inst); zmax = zmax_(num_inst); nbz = nbz_(num_inst);
      coor = [coorx_(num_inst); coory_(num_inst); coorz_(num_inst)];
      taille = cplx*(nbx*nby + nbx*nbz + nby*nbz);
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);
      
      X = linspace(xmin, xmax, nbx);
      Y = linspace(ymin, ymax, nby);
      Z = linspace(zmin, zmax, nbz);

      V1 = reshape(M(1:nby*nbz), nby, nbz);
      V2 = reshape(M((nby*nbz+1):(nbx*nbz+nby*nbz)), nbx, nbz);
      V3 = reshape(M((nby*nbz+nbx*nbz+1):(nbx*nby+nbx*nbz+nby*nbz)), nbx, nby);

      nbxy = max(nbx,nby);
      nbyz = max(nby,nbz);
      U = zeros(nbxy, nbyz, 3);
      V1c = V1; V2c = V2; V3c = V3;
      if (nby < nbxy)
        V1c = interp2(Y,Z,V1,linspace(ymin,ymax,nbxy),linspace(zmin,zmax,nbyz)');
      end
      if (nbz < nbyz)
        V1c = interp2(Y,Z,V1,linspace(ymin,ymax,nbxy),linspace(zmin,zmax,nbyz)');
        V2c = interp2(X,Z,V2,linspace(xmin,xmax,nbxy),linspace(zmin,zmax,nbyz)');
      end
      if (nbx < nbxy)
        V2c = interp2(X,Z,V2,linspace(xmin,xmax,nbxy),linspace(zmin,zmax,nbyz)');
        V3c = interp2(X,Y,V3,linspace(xmin,xmax,nbxy),linspace(ymin,ymax,nbyz)');
      end
      if (nby < nbyz)
        V3c = interp2(X,Y,V3,linspace(xmin,xmax,nbxy),linspace(ymin,ymax,nbyz)');
      end
      
      U(:,:,1) = transpose(V1c);
      U(:,:,2) = V2c;
      U(:,:,3) = V3c;
      if (raff == 1)
        V = U;
        XI = X; YI = Y; ZI = Z;
      else
        [YI,ZI] = meshgrid(linspace(ymin, ymax, raff*nby),linspace(zmin, zmax, raff*nbz));
        V1 = interp2(Y, Z, V1, YI, ZI);
        [XI,ZI] = meshgrid(linspace(xmin, xmax, raff*nbx),linspace(zmin, zmax, raff*nbz));
        V2 = interp2(X, Z, V2, XI, ZI);
        [XI,YI] = meshgrid(linspace(xmin, xmax, raff*nbx),linspace(ymin, ymax, raff*nby));
        V3 = interp2(X, Y, V3, XI, YI);
        V(:,:,1) = transpose(V1);
        V(:,:,2) = V2; V(:,:,3) = V3;
        XI = linspace(xmin,xmax,raff*nbx);
        YI = linspace(ymin,ymax,raff*nby);
        ZI = linspace(zmin,zmax,raff*nbz);
      end
      
    elseif (type_grid == 2)
 
      % SismoPlane
      offset = 0;
      for i = 1:nb_grids
        xmin_(i) = fread(fid, 1, prec);
        xmax_(i) = fread(fid, 1, prec);
        ymin_(i) = fread(fid, 1, prec);
        ymax_(i) = fread(fid, 1, prec);
        zmin_(i) = fread(fid, 1, prec);
        zmax_(i) = fread(fid, 1, prec);
        centerx_(i) = fread(fid, 1, prec);
        centery_(i) = fread(fid, 1, prec);
        centerz_(i) = fread(fid, 1, prec);
        nbx_(i) = fread(fid, 1, 'int');
        nby_(i) = fread(fid, 1, 'int');
        if (i < num_inst)
          offset = offset + nbx_(i)*nby_(i);
        end
      end 
      origin(1) = xmin_(num_inst); extA(1) = xmax_(num_inst);
      origin(2) = ymin_(num_inst); extA(2) = ymax_(num_inst);
      origin(3) = zmin_(num_inst); extA(3) = zmax_(num_inst);
      extB(1) = centerx_(num_inst); extB(2) = centery_(num_inst); extB(3) = centerz_(num_inst);
      nbx = nbx_(num_inst); nby = nby_(num_inst);
      n = fread(fid, 1, 'int');
      taille = cplx*nbx*nby;
      % we read values related to the required snapshot
      fseek(fid, offset*prec_size, 'cof');
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);

      Tx = linspace(0, 1, nbx);
      Ty = linspace(0, 1, nby);
      [Tx, Ty] = meshgrid(Tx, Ty);
      U = reshape(M, nbx, nby); U = U.';
      if (raff == 1)
        V = U;
      else
        [Txi, Tyi] = meshgrid(linspace(0, 1, raff*nbx), linspace(0, 1, raff*nby));
        V = interp2(Tx, Ty, U, Txi, Tyi);
        nbx = nbx*raff; nby = nby*raff;
        Tx = Txi; Ty = Tyi;
      end
      XI = (extA(1)-origin(1))*Tx + (extB(1)-origin(1))*Ty + origin(1);
      YI = (extA(2)-origin(2))*Tx + (extB(2)-origin(2))*Ty + origin(2);
      ZI = (extA(3)-origin(3))*Tx + (extB(3)-origin(3))*Ty + origin(3);

    elseif (type_grid == 3)

      % SismoLine
      offset = 0;
      for i = 1:nb_grids
        xmin_(i) = fread(fid, 1, prec);
        xmax_(i) = fread(fid, 1, prec);
        ymin_(i) = fread(fid, 1, prec);
        ymax_(i) = fread(fid, 1, prec);
        zmin_(i) = fread(fid, 1, prec);
        zmax_(i) = fread(fid, 1, prec);
        nbx_(i) = fread(fid, 1, 'int');
        if (i < num_inst)
          offset = offset + nbx_(i);
        end
      end 
      xmin = xmin_(num_inst); xmax = xmax_(num_inst);
      ymin = ymin_(num_inst); ymax = ymax_(num_inst);
      zmin = zmin_(num_inst); zmax = zmax_(num_inst);
      nbx = nbx_(num_inst);
      n = fread(fid, 1, 'int');
      taille = cplx*nbx;
      % we read values related to the required snapshot
      fseek(fid, offset*prec_size, 'cof');
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);

      T = linspace(0, 1, nbx); 
      U = reshape(M, nbx, 1);
      if (raff == 1)
        V = U;
      else
        TI = linspace(0, 1, raff*nbx);
        V = interp1(T, U, TI);
        nbx = nbx*raff;
      end
      XI = linspace(xmin, xmax, nbx);
      YI = linspace(ymin, ymax, nbx);
      ZI = linspace(zmin, zmax, nbx);
      
    elseif (type_grid == 4)

      % SismoPoint
      offset = 0;
      for i = 1:nb_grids
        xmin_(i) = fread(fid, 1, prec);
        ymin_(i) = fread(fid, 1, prec);
        zmin_(i) = fread(fid, 1, prec);
        if (i < num_inst)
          offset = offset + 1;
        end
      end 
      xmin = xmin_(num_inst);
      ymin = ymin_(num_inst);
      zmin = ymin_(num_inst);
      n = fread(fid, 1, 'int');
      taille = cplx;
      % we read values related to the required snapshot
      fseek(fid, offset*prec_size, 'cof');
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);

      XI = xmin;
      YI = ymin;
      ZI = zmin;
      V = M;

    elseif (type_grid == 5)
      
      % SismoPointsFile
      offset = 0;
      for i = 1:nb_grids
        nbx_(i) = fread(fid, 1, 'int');
        PT_(i).coor = fread(fid, 3*nbx_(i), prec);
        if (i < num_inst)
          offset = offset + nbx_(i);
        end
      end 
      PT = PT_(num_inst).coor;
      nbx = nbx_(num_inst);
      n = fread(fid, 1, 'int');
      taille = cplx*nbx;
      % we read values related to the required snapshot
      fseek(fid, offset*prec_size, 'cof');
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);

      XI = PT(1:3:end);
      YI = PT(2:3:end);
      ZI = PT(3:3:end);
      V = reshape(M, nbx, 1);
    elseif (type_grid == 6)
        % Circle
      offset = 0;
      for i = 1:nb_grids
        centerx_(i) = fread(fid, 1, prec);
        centery_(i) = fread(fid, 1, prec);
        centerz_(i) = fread(fid, 1, prec);
        normalex_(i) = fread(fid, 1, prec);
        normaley_(i) = fread(fid, 1, prec);
        normalez_(i) = fread(fid, 1, prec);
        radiusA_(i) = fread(fid, 1, prec);
        radiusB_(i) = fread(fid, 1, prec);
        nbx_(i) = fread(fid, 1, 'int');
        if (i < num_inst)
          offset = offset + nbx_(i);
        end
      end 
      centerx = centerx_(num_inst); radiusA = radiusA_(num_inst);
      centery = centery_(num_inst); radiusB = radiusB_(num_inst);
      centerz = centerz_(num_inst); normale(1) = normalex_(num_inst);
      normale(2) = normaley_(num_inst); normale(3) = normalez_(num_inst);
      nbx = nbx_(num_inst);
      n = fread(fid, 1, 'int');
      taille = cplx*nbx;
      % we read values related to the required snapshot
      fseek(fid, offset*prec_size, 'cof');
      data = fread(fid, taille, prec);
      if (cplx == 2)
        M = data(1:2:taille)+1i*data(2:2:taille);
      else
        M = data;
      end
      fclose(fid);

      % finding the two vectors of plane, knowing the normale
      [coord, perm] = sort(abs(normale))
      vec_u = zeros(3,1); vec_u(perm(3)) = -normale(perm(2));
      vec_u(perm(2)) = normale(perm(3));
      vec_v(1) = normale(2)*vec_u(3) - normale(3)*vec_u(2);
      vec_v(2) = normale(3)*vec_u(1) - normale(1)*vec_u(3);
      vec_v(3) = normale(1)*vec_u(2) - normale(2)*vec_u(1);
      
      U = reshape(M, nbx, 1);
      if (raff == 1)
        V = U;
        teta = linspace(0, 2*pi, nbx+1); teta = teta(1:nbx);
        XI = radiusA*vec_u(1)*cos(teta) + radiusB*vec_v(1)*sin(teta) + centerx;
        YI = radiusA*vec_u(2)*cos(teta) + radiusB*vec_v(2)*sin(teta) + centery;
        ZI = radiusA*vec_u(3)*cos(teta) + radiusB*vec_v(3)*sin(teta) + centerz;
      else
        T = linspace(0, 1, nbx); TI = linspace(0, 1, raff*nbx);
        teta = linspace(0, 2*pi, raff*nbx+1); teta = teta(1:raff*nbx);
        XI = radiusA*vec_u(1)*cos(teta) + radiusB*vec_v(1)*sin(teta) + centerx;
        YI = radiusA*vec_u(2)*cos(teta) + radiusB*vec_v(2)*sin(teta) + centery;
        ZI = radiusA*vec_u(3)*cos(teta) + radiusB*vec_v(3)*sin(teta) + centerz;
        V = interp1(T, U, TI);
      end
    end
  end
